%define oname   luasql

Name:           lua-sql
Version:        2.6.0
Release:        %mkrel 2
Summary:        Database connectivity for the Lua programming language
Group:          Development/Other
License:        MIT
URL:            https://keplerproject.github.io/luasql/
Source0:        https://github.com/keplerproject/luasql/archive/%{version}.tar.gz#/luasql-%{version}.tar.gz
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  mariadb-devel
BuildRequires:  postgresql-devel
Requires:       %{name}-sqlite = %{version}-%{release}
Requires:       %{name}-mysql = %{version}-%{release}
Requires:       %{name}-postgresql = %{version}-%{release}
Recommends:     %{name}-doc = %{version}-%{release}

%description
LuaSQL is a simple interface from Lua to a DBMS. This package of LuaSQL
supports MySQL, SQLite and PostgreSQL databases. You can execute arbitrary SQL
statements and it allows for retrieving results in a row-by-row cursor fashion.

%files

#------------------------------------------------------------------

%package        doc
Summary:        Documentation for LuaSQL
Group:          Development/Other

%description    doc
LuaSQL is a simple interface from Lua to a DBMS. This package contains the
documentation for LuaSQL.

%files doc
%doc README doc/us/*

#------------------------------------------------------------------

%package        sqlite
Summary:        SQLite database connectivity for the Lua programming language
Group:          Development/Other

%description    sqlite
LuaSQL is a simple interface from Lua to a DBMS. This package provides access
to SQLite databases.

%files          sqlite
%dir %{lua_libdir}/%{oname}
%{lua_libdir}/%{oname}/sqlite3.so

#------------------------------------------------------------------

%package        mysql
Summary:        MySQL database connectivity for the Lua programming language
Group:          Development/Other

%description    mysql
LuaSQL is a simple interface from Lua to a DBMS. This package provides access
to MySQL databases.

%files          mysql
%dir %{lua_libdir}/%{oname}
%{lua_libdir}/%{oname}/mysql.so

#------------------------------------------------------------------

%package        postgresql
Summary:        PostgreSQL database connectivity for the Lua programming language
Group:          Development/Other

%description    postgresql
LuaSQL is a simple interface from Lua to a DBMS. This package provides access
to PostgreSQL databases.

%files          postgresql
%dir %{lua_libdir}/%{oname}
%{lua_libdir}/%{oname}/postgres.so

#------------------------------------------------------------------

%prep
%autosetup -n luasql-%{version} -p1


%build
export LIB_OPTION="%{ldflags} -shared"
%make_build sqlite3 PREFIX=%{_prefix} DRIVER_INCS_sqlite3="`pkg-config --cflags sqlite3`" DRIVER_LIBS_sqlite3="-llua `pkg-config --libs sqlite3`" DEFS="%{optflags} -fPIC -std=c99 -DLUA_COMPAT_APIINTCASTS"
%make_build postgres PREFIX=%{_prefix} DRIVER_INCS_postgres="" DRIVER_LIBS_postgres="-llua -lpq" DEFS="%{optflags} -fPIC -std=c99 -DLUA_COMPAT_APIINTCASTS" WARN=
%make_build mysql PREFIX=%{_prefix} DRIVER_INCS_mysql="`mysql_config --include`" DRIVER_LIBS_mysql="-llua `mysql_config --libs`" DEFS="%{optflags} -fPIC -std=c99 -DLUA_COMPAT_APIINTCASTS"


%install
%make_install PREFIX=%{buildroot}%{_prefix} LUA_LIBDIR=%{buildroot}%{lua_libdir} LUA_DIR=%{buildroot}%{lua_pkgdir} T=sqlite3
%make_install PREFIX=%{buildroot}%{_prefix} LUA_LIBDIR=%{buildroot}%{lua_libdir} LUA_DIR=%{buildroot}%{lua_pkgdir} T=postgres
%make_install PREFIX=%{buildroot}%{_prefix} LUA_LIBDIR=%{buildroot}%{lua_libdir} LUA_DIR=%{buildroot}%{lua_pkgdir} T=mysql


%changelog
* Sat Apr 02 2022 umeabot <umeabot> 2.6.0-2.mga9
+ Revision: 1841118
- Mageia 9 Mass Rebuild

* Sun Apr 04 2021 wally <wally> 2.6.0-1.mga9
+ Revision: 1713383
- new version 2.6.0

* Mon Mar 29 2021 wally <wally> 2.3.5-5.mga9
+ Revision: 1711638
- build with latest lua

* Sun Jul 26 2020 daviddavid <daviddavid> 2.3.5-4.mga8
+ Revision: 1609035
- fix build with mariadb 10.5.4

* Thu Feb 13 2020 umeabot <umeabot> 2.3.5-3.mga8
+ Revision: 1514903
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 2.3.5-2.mga7
+ Revision: 1299378
- Mageia 7 Mass Rebuild

* Wed Apr 04 2018 kekepower <kekepower> 2.3.5-1.mga7
+ Revision: 1215169
- Update to version 2.3.5

* Sat Dec 23 2017 wally <wally> 2.3.1-2.mga7
+ Revision: 1184307
- add patch to fix build with new mariadb 10.2
- rebuild for new mariadb

* Mon Mar 28 2016 shlomif <shlomif> 2.3.1-1.mga6
+ Revision: 995989
- New version 2.3.1

* Mon Feb 08 2016 umeabot <umeabot> 2.3.0-6.mga6
+ Revision: 950850
- Mageia 6 Mass Rebuild

* Tue Nov 25 2014 cjw <cjw> 2.3.0-5.mga5
+ Revision: 798917
- rebuild against postgresql9.4

* Wed Oct 15 2014 umeabot <umeabot> 2.3.0-4.mga5
+ Revision: 746251
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.3.0-3.mga5
+ Revision: 682032
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sun Aug 31 2014 akien <akien> 2.3.0-2.mga5
+ Revision: 669805
- Readd empty %%files for main package acting as a meta-package

* Sun Aug 10 2014 akien <akien> 2.3.0-1.mga5
+ Revision: 661539
- Version 2.3.0

* Fri Oct 18 2013 umeabot <umeabot> 2.1.1-11.mga4
+ Revision: 507605
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 2.1.1-10.mga3
+ Revision: 359072
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 pterjan <pterjan> 2.1.1-9.mga3
+ Revision: 334424
- Force Lua 5.1

* Thu Mar 24 2011 dmorgan <dmorgan> 2.1.1-8.mga1
+ Revision: 77055
- Rebuild against new mysql

* Sun Mar 13 2011 shikamaru <shikamaru> 2.1.1-7.mga1
+ Revision: 70280
- imported package lua-sql


* Sat Mar 12 2011 Rémy Clouard <shikamaru@mandriva.org> 2.1.1-7.mga1
- clean spec (buildroot)

* Sat Jan 01 2011 Oden Eriksson <oeriksson@mandriva.com> 2.1.1-6mdv2011.0
+ Revision: 627256
- rebuilt against mysql-5.5.8 libs, again

* Thu Dec 30 2010 Oden Eriksson <oeriksson@mandriva.com> 2.1.1-5mdv2011.0
+ Revision: 626538
- rebuilt against mysql-5.5.8 libs

* Wed Dec 08 2010 Rémy Clouard <shikamaru@mandriva.org> 2.1.1-3mdv2011.0
+ Revision: 616184
- rebuild for the mass rebuild

* Mon Sep 14 2009 Thierry Vignaud <tv@mandriva.org> 2.1.1-2mdv2010.0
+ Revision: 439656
- rebuild

* Mon Dec 29 2008 Jérôme Soyer <saispo@mandriva.org> 2.1.1-1mdv2009.1
+ Revision: 320764
- Fix RPM Group
- Fix BR
- SPEC Cleanup
- import lua-sql


